.. _apps-socket:

=================
Socket Servers
=================

.. automodule:: pulsar.apps.socket


API
=========

Socket Server
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: SocketServer
   :members:
   :member-order: bysource


UDP Socket Server
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: UdpSocketServer
   :members:
   :member-order: bysource
